==> overate-vntech.nestjs.aloline.entity-test-0.1.1.tgz: package/src/enums/message.enum.ts <==
export enum MESSAGE_PINNED_STATUS {
  UNPINNED,
  PINNED,
}

export enum MESSAGE_REACTION_TYPE {
  LIKE = 1,
  LOVE = 2,
  HAHA = 3,
  WOW = 4,
  SAD = 5,
  ANGRY = 6,
}

export const MESSAGE_REACTION_NAME = {
  [MESSAGE_REACTION_TYPE.LIKE]: 'no_of_like',
  [MESSAGE_REACTION_TYPE.LOVE]: 'no_of_love',
  [MESSAGE_REACTION_TYPE.HAHA]: 'no_of_haha',
  [MESSAGE_REACTION_TYPE.WOW]: 'no_of_wow',
  [MESSAGE_REACTION_TYPE.SAD]: 'no_of_sad',
  [MESSAGE_REACTION_TYPE.ANGRY]: 'no_of_angry',
};

export enum MESSAGE_VOTE_STATUS {
  DELETED = 0,
  ACTIVE = 1,
}

export enum MESSAGE_STATUS {
  DELETED = 0,
  ACTIVE = 1,
}

export enum MESSAGE_TYPE {
  TEXT = 1,
  IMAGE = 2,
  VIDEO = 3,
  AUDIO = 4,
  FILE = 5,
  REPLY = 6,
  UPDATE_NAME = 7,
  UPDATE_AVATAR = 8,
  UPDATE_BACKGROUND = 9,
  REMOVE_USER = 10,
  ADD_NEW_USER = 11,
  CHANGE_PERMISSION_USER = 12,
  USER_OUT_GROUP = 13,
  REVOKE_MESSAGE = 14,
  STICKER = 15,
  NEW_GROUP = 16,
  YOU_IS_CHANGE_PERMISSION = 17,
  UPDATE_is_update_profile = 18,
  UPDATE_is_pinned = 19,
  UPDATE_is_create_reminder = 20,
  UPDATE_is_create_vote = 21,
  UPDATE_is_confirm_new_member = 22,
  UPDATE_is_off_confirm_new_member = 23,
  UPDATE_is_view_old_message_with_new_member = 24,
  UPDATE_is_join_with_link = 25,
  UPDATE_is_send_message = 26,
  PINNED = 27,
  REMOVE_PINNED = 28,
  ADD_DEPUTY = 29,
  REMOVE_DEPUTY = 30,
  CREATE_VOTE = 31,
  VOTE = 32,
  CHANGE_VOTE = 33,
  ADD_VOTE_OPTION = 34,
  WAITING_CONFIRM = 35,
  BLOCK_VOTE = 36,
  MESSAGE_VOTE_PINNED = 37,
  REMOVE_MESSAGE_VOTE_PINNED = 38,
  SHARE = 39,
}

==> overate-vntech.nestjs.aloline.entity-test-0.1.5.tgz: package/src/enums/message.enum.ts <==
export enum MESSAGE_PINNED_STATUS {
  UNPINNED,
  PINNED,
}

export enum MESSAGE_REACTION_TYPE {
  LIKE = 1,
  LOVE = 2,
  HAHA = 3,
  WOW = 4,
  SAD = 5,
  ANGRY = 6,
}

export const MESSAGE_REACTION_NAME = {
  [MESSAGE_REACTION_TYPE.LIKE]: 'no_of_like',
  [MESSAGE_REACTION_TYPE.LOVE]: 'no_of_love',
  [MESSAGE_REACTION_TYPE.HAHA]: 'no_of_haha',
  [MESSAGE_REACTION_TYPE.WOW]: 'no_of_wow',
  [MESSAGE_REACTION_TYPE.SAD]: 'no_of_sad',
  [MESSAGE_REACTION_TYPE.ANGRY]: 'no_of_angry',
};

export enum MESSAGE_VOTE_STATUS {
  BLOCK = 0,
  ACTIVE = 1,
}

export enum MESSAGE_STATUS {
  DELETED = 0,
  ACTIVE = 1,
}

export enum MESSAGE_SYSTEM_TYPE {
  UPDATE_NAME = 7,
  UPDATE_AVATAR = 8,
  UPDATE_BACKGROUND = 9,
  REMOVE_USER = 10,
  ADD_NEW_USER = 11,
  CHANGE_PERMISSION_USER = 12,
  USER_OUT_GROUP = 13,
  REVOKE_MESSAGE = 14,
  NEW_GROUP = 16,
  YOU_IS_CHANGE_PERMISSION = 17,
  MESSAGE_UPDATE_PROFILE = 18,
  UPDATE_IS_PINNED = 19,
  UPDATE_IS_CREATE_REMINDER = 20,
  UPDATE_IS_CREATE_VOTE = 21,
  UPDATE_IS_CONFIRM_NEW_MEMBER = 22,
  UPDATE_IS_OFF_CONFIRM_NEW_MEMBER = 23,
  UPDATE_IS_VIEW_OLD_MESSAGE_WITH_NEW_MEMBER = 24,
  UPDATE_IS_JOIN_WITH_LINK = 25,
  MESSAGE_UPDATE_SEND_MESSAGE = 26,
  PINNED = 27,
  REMOVE_PINNED = 28,
  ADD_DEPUTY = 29,
  REMOVE_DEPUTY = 30,
  CREATE_VOTE = 31,
  VOTE = 32,
  CHANGE_VOTE = 33,
  ADD_VOTE_OPTION = 34,
  WAITING_CONFIRM = 35,
  BLOCK_VOTE = 36,
  MESSAGE_VOTE_PINNED = 37,
  REMOVE_MESSAGE_VOTE_PINNED = 38,
}

export enum NON_MESSAGE_SYSTEM_TYPE {
  TEXT = 1,
  IMAGE = 2,
  VIDEO = 3,
  AUDIO = 4,
  FILE = 5,
  REPLY = 6,
  STICKER = 15,
}

export const MESSAGE_TYPE = {
  ...NON_MESSAGE_SYSTEM_TYPE,
  ...MESSAGE_SYSTEM_TYPE,
};
export type MESSAGE_TYPE = NON_MESSAGE_SYSTEM_TYPE | MESSAGE_SYSTEM_TYPE;

export interface IMessageUserTarget {
  user_id: number;
  full_name: string;
  avatar: string;
}
